=============
Sage Explorer
=============

.. image:: https://mybinder.org/badge.svg
   :target: https://mybinder.org/v2/gh/sagemath/sage-explorer/master

A `Jupyter Notebook <http://jupyter.org>`_ widget for exploring `SageMath <http://www.sagemath.org>`_ objects.


Installation
------------

Try it on binder
^^^^^^^^^^^^^^^^

`demo <https://mybinder.org/v2/gh/sagemath/sage-explorer/master?filepath=demo_sage_explorer.ipynb>`_


Local install from source
^^^^^^^^^^^^^^^^^^^^^^^^^

Download the source from the git repository::

    $ git clone https://github.com/sagemath/sage-explorer.git

Change to the root directory and run::

    $ sage -pip install --upgrade --no-index -v .

For convenience this package contains a [makefile](makefile) with this
and other often used commands. Should you wish too, you can use the
shorthand::

    $ make install

Install from PyPI
^^^^^^^^^^^^^^^^^^

Sage Explorer is distributed on PyPI.

    $ sage -pip install sage_explorer

Usage
-----

See the `demo notebook <demo_sage_explorer.ipynb>`_.
